@@ -9,22 +9,26 @@ class FileRegistry:
     filelist = ()
     ex = []
 
-    def __init__(self, kind, name, ftype='csv', path=''):
+    def __init__(self, kind, name, ftype='csv', rootpath='', path=''):
         self.name = name
+        if rootpath == '':
+            rootpath = '/Volumes/GoogleDrive/My Drive/_Data/'
         if kind == 'options':
-            self.path = '/Volumes/GoogleDrive/My Drive/Premind_Light/Xignite/Options/' + path + '/'
+            self.path = rootpath + 'Premind_Light/Xignite/Options/' + path + '/'
         elif kind == 'options_main':
-            self.path = '/Volumes/GoogleDrive/My Drive/Premind_Light/Xignite/OptionsMain/' + path + '/'
+            self.path = rootpath + 'Premind_Light/Xignite/OptionsMain/' + path + '/'
         elif kind == 'daily_price':
-            self.path = '/Volumes/GoogleDrive/My Drive/Premind_Light/Xignite/DailyPrice/' + path + '/'
+            self.path = rootpath + 'Premind_Light/Xignite/DailyPrice/' + path + '/'
         elif kind == 'xlsx':
-            self.path = '/Volumes/GoogleDrive/My Drive/__Premind/6. Product-Tech/14. FraudArb' + path + '/'
+            self.path = rootpath + '__Premind/6. Product-Tech/14. FraudArb' + path + '/'
         elif kind == 'historic':
-            self.path = '/Volumes/GoogleDrive/My Drive/__Premind/6. Product-Tech/14. FraudArb/HistoricData' + path + '/'
+            self.path = rootpath + '__Premind/6. Product-Tech/14. FraudArb/HistoricData' + path + '/'
         elif kind == 'historic_ticker':
-            self.path = '/Volumes/GoogleDrive/My Drive/__Premind/6. Product-Tech/14. FraudArb/Articles' + path + '/'
+            self.path = rootpath + '__Premind/6. Product-Tech/14. FraudArb/Articles' + path + '/'
         elif kind == 'ticker':
-            self.path = '/Volumes/GoogleDrive/My Drive/__Python/Premind_Light/Analytics/Analytics_Cloud/Analytics_Docker/data/FraudArb/Tickers' + path + '/'
+            self.path = rootpath + '__Python/Premind_Light/Analytics/Analytics_Cloud/Analytics_Docker/data/FraudArb/Tickers' + path + '/'
+        elif kind == 'wordanalysis':
+            self.path = rootpath + kind + "/" + path + '/'
 
         if ftype == "":
             self.fullpath = self.path + name
